OrderStatus

Enum OrderStatus 

#[repr(u8)]
pub enum OrderStatus { PendingNew = 1, New = 2, PartiallyFilled = 3, Filled = 4, PendingCancel = 5, Cancelled = 6, PendingReplace = 7, Replaced = 8, Rejected = 9, Expired = 10, Suspended = 11, Unknown = 12, }
FIX-style canonical order status.

Variants



PendingNew = 1

Local request is pending submission/acknowledgement.



New = 2

Venue accepted the live order.



PartiallyFilled = 3

Order has at least one fill and remaining leaves quantity.



Filled = 4

Order is fully filled.



PendingCancel = 5

Cancel request is pending.



Cancelled = 6

Order is cancelled.



PendingReplace = 7

Cancel/replace request is pending.



Replaced = 8

Order was replaced.



Rejected = 9

Order was rejected.



Expired = 10

Order expired.



Suspended = 11

Order is suspended.



Unknown = 12

Order state could not be reconciled.

Implementations

Source

impl OrderStatus

pub const fn is_terminal(self) -> bool

Returns true when no further venue activity is expected.